# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instalabel.client.models.polygon_annotation import PolygonAnnotation

class TestPolygonAnnotation(unittest.TestCase):
    """PolygonAnnotation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PolygonAnnotation:
        """Test PolygonAnnotation
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PolygonAnnotation`
        """
        model = PolygonAnnotation()
        if include_optional:
            return PolygonAnnotation(
                id = '',
                class_id = '',
                class_name = '',
                color = '',
                type = 'polygon',
                class_attributes_selections = {
                    'key' : [
                        ''
                        ]
                    },
                class_information = instalabel.client.models.class_information.ClassInformation(
                    id = '', 
                    name = '', 
                    color = '', 
                    description = '', 
                    attributes_selections_id_map = {
                        'key' : [
                            ''
                            ]
                        }, 
                    attributes_selections = [
                        instalabel.client.models.attribute_selection.AttributeSelection(
                            name = '', 
                            labels = [
                                ''
                                ], 
                            values = [
                                ''
                                ], )
                        ], ),
                points = [
                    [
                        56
                        ]
                    ],
                is_complete = True
            )
        else:
            return PolygonAnnotation(
                id = '',
                class_id = '',
                class_name = '',
                color = '',
                class_information = instalabel.client.models.class_information.ClassInformation(
                    id = '', 
                    name = '', 
                    color = '', 
                    description = '', 
                    attributes_selections_id_map = {
                        'key' : [
                            ''
                            ]
                        }, 
                    attributes_selections = [
                        instalabel.client.models.attribute_selection.AttributeSelection(
                            name = '', 
                            labels = [
                                ''
                                ], 
                            values = [
                                ''
                                ], )
                        ], ),
                points = [
                    [
                        56
                        ]
                    ],
        )
        """

    def testPolygonAnnotation(self):
        """Test PolygonAnnotation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
