# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instalabel.client.api.projects_api import ProjectsApi


class TestProjectsApi(unittest.TestCase):
    """ProjectsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ProjectsApi()

    def tearDown(self) -> None:
        pass

    def test_create_project_api_v1_projects_post(self) -> None:
        """Test case for create_project_api_v1_projects_post

        Create Project
        """
        pass

    def test_read_project_api_v1_projects_project_id_get(self) -> None:
        """Test case for read_project_api_v1_projects_project_id_get

        Read Project
        """
        pass

    def test_read_projects_api_v1_projects_get(self) -> None:
        """Test case for read_projects_api_v1_projects_get

        Read Projects
        """
        pass

    def test_update_project_api_v1_projects_project_id_put(self) -> None:
        """Test case for update_project_api_v1_projects_project_id_put

        Update Project
        """
        pass


if __name__ == '__main__':
    unittest.main()
