# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instalabel.client.api.aws_integrations_api import AwsIntegrationsApi


class TestAwsIntegrationsApi(unittest.TestCase):
    """AwsIntegrationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AwsIntegrationsApi()

    def tearDown(self) -> None:
        pass

    def test_create_integration_api_v1_aws_integrations_post(self) -> None:
        """Test case for create_integration_api_v1_aws_integrations_post

        Create Integration
        """
        pass

    def test_delete_integration_api_v1_aws_integrations_integration_id_delete(self) -> None:
        """Test case for delete_integration_api_v1_aws_integrations_integration_id_delete

        Delete Integration
        """
        pass

    def test_get_integration_api_v1_aws_integrations_integration_id_get(self) -> None:
        """Test case for get_integration_api_v1_aws_integrations_integration_id_get

        Get Integration
        """
        pass

    def test_get_workspace_integrations_api_v1_aws_integrations_workspace_workspace_id_get(self) -> None:
        """Test case for get_workspace_integrations_api_v1_aws_integrations_workspace_workspace_id_get

        Get Workspace Integrations
        """
        pass


if __name__ == '__main__':
    unittest.main()
