# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instalabel.client.models.option import Option

class TestOption(unittest.TestCase):
    """Option unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Option:
        """Test Option
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Option`
        """
        model = Option()
        if include_optional:
            return Option(
                id = '',
                label = '',
                value = '',
                attributes = [
                    instalabel.client.models.attribute.Attribute(
                        id = '', 
                        name = '', 
                        type = 'radio', 
                        required = True, 
                        options = [
                            instalabel.client.models.option.Option(
                                id = '', 
                                label = '', 
                                value = '', )
                            ], )
                    ]
            )
        else:
            return Option(
                label = '',
                value = '',
        )
        """

    def testOption(self):
        """Test Option"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
