# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instalabel.client.models.project_image_response import ProjectImageResponse

class TestProjectImageResponse(unittest.TestCase):
    """ProjectImageResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProjectImageResponse:
        """Test ProjectImageResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProjectImageResponse`
        """
        model = ProjectImageResponse()
        if include_optional:
            return ProjectImageResponse(
                images = [
                    instalabel.client.models.image_response.ImageResponse(
                        image_id = '', 
                        project_id = '', 
                        user_id = '', 
                        filename = '', 
                        status = '', 
                        annotations_count = 56, 
                        annotations = instalabel.client.models.annotation_data.AnnotationData(
                            rectangles = [
                                instalabel.client.models.b_box_annotation.BBoxAnnotation(
                                    id = '', 
                                    class_id = '', 
                                    class_name = '', 
                                    color = '', 
                                    type = 'boundingBox', 
                                    class_attributes_selections = {
                                        'key' : [
                                            ''
                                            ]
                                        }, 
                                    class_information = instalabel.client.models.class_information.ClassInformation(
                                        id = '', 
                                        name = '', 
                                        color = '', 
                                        description = '', 
                                        attributes_selections_id_map = {
                                            'key' : [
                                                ''
                                                ]
                                            }, 
                                        attributes_selections = [
                                            instalabel.client.models.attribute_selection.AttributeSelection(
                                                name = '', 
                                                labels = [
                                                    ''
                                                    ], 
                                                values = [
                                                    ''
                                                    ], )
                                            ], ), 
                                    x = 56, 
                                    y = 56, 
                                    width = 56, 
                                    height = 56, 
                                    fill = '', 
                                    stroke = '', )
                                ], 
                            polygons = [
                                instalabel.client.models.polygon_annotation.PolygonAnnotation(
                                    id = '', 
                                    class_id = '', 
                                    class_name = '', 
                                    color = '', 
                                    type = 'polygon', 
                                    class_attributes_selections = {
                                        'key' : [
                                            ''
                                            ]
                                        }, 
                                    class_information = instalabel.client.models.class_information.ClassInformation(
                                        id = '', 
                                        name = '', 
                                        color = '', 
                                        description = '', 
                                        attributes_selections_id_map = {
                                            'key' : [
                                                ''
                                                ]
                                            }, ), 
                                    points = [
                                        [
                                            56
                                            ]
                                        ], 
                                    is_complete = True, )
                                ], ), 
                        created_at = '', 
                        updated_at = '', 
                        presigned_url = '', )
                    ],
                next_key = '',
                count = 56
            )
        else:
            return ProjectImageResponse(
                images = [
                    instalabel.client.models.image_response.ImageResponse(
                        image_id = '', 
                        project_id = '', 
                        user_id = '', 
                        filename = '', 
                        status = '', 
                        annotations_count = 56, 
                        annotations = instalabel.client.models.annotation_data.AnnotationData(
                            rectangles = [
                                instalabel.client.models.b_box_annotation.BBoxAnnotation(
                                    id = '', 
                                    class_id = '', 
                                    class_name = '', 
                                    color = '', 
                                    type = 'boundingBox', 
                                    class_attributes_selections = {
                                        'key' : [
                                            ''
                                            ]
                                        }, 
                                    class_information = instalabel.client.models.class_information.ClassInformation(
                                        id = '', 
                                        name = '', 
                                        color = '', 
                                        description = '', 
                                        attributes_selections_id_map = {
                                            'key' : [
                                                ''
                                                ]
                                            }, 
                                        attributes_selections = [
                                            instalabel.client.models.attribute_selection.AttributeSelection(
                                                name = '', 
                                                labels = [
                                                    ''
                                                    ], 
                                                values = [
                                                    ''
                                                    ], )
                                            ], ), 
                                    x = 56, 
                                    y = 56, 
                                    width = 56, 
                                    height = 56, 
                                    fill = '', 
                                    stroke = '', )
                                ], 
                            polygons = [
                                instalabel.client.models.polygon_annotation.PolygonAnnotation(
                                    id = '', 
                                    class_id = '', 
                                    class_name = '', 
                                    color = '', 
                                    type = 'polygon', 
                                    class_attributes_selections = {
                                        'key' : [
                                            ''
                                            ]
                                        }, 
                                    class_information = instalabel.client.models.class_information.ClassInformation(
                                        id = '', 
                                        name = '', 
                                        color = '', 
                                        description = '', 
                                        attributes_selections_id_map = {
                                            'key' : [
                                                ''
                                                ]
                                            }, ), 
                                    points = [
                                        [
                                            56
                                            ]
                                        ], 
                                    is_complete = True, )
                                ], ), 
                        created_at = '', 
                        updated_at = '', 
                        presigned_url = '', )
                    ],
                count = 56,
        )
        """

    def testProjectImageResponse(self):
        """Test ProjectImageResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
