# coding: utf-8

# flake8: noqa

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# import apis into sdk package
from instalabel.client.api.auth_api import AuthApi
from instalabel.client.api.aws_integrations_api import AwsIntegrationsApi
from instalabel.client.api.images_api import ImagesApi
from instalabel.client.api.projects_api import ProjectsApi
from instalabel.client.api.workspaces_api import WorkspacesApi

# import ApiClient
from instalabel.client.api_response import ApiResponse
from instalabel.client.api_client import ApiClient
from instalabel.client.configuration import Configuration
from instalabel.client.exceptions import OpenApiException
from instalabel.client.exceptions import ApiTypeError
from instalabel.client.exceptions import ApiValueError
from instalabel.client.exceptions import ApiKeyError
from instalabel.client.exceptions import ApiAttributeError
from instalabel.client.exceptions import ApiException

# import models into sdk package
from instalabel.client.models.aws_integration_create import AWSIntegrationCreate
from instalabel.client.models.aws_integration_response import AWSIntegrationResponse
from instalabel.client.models.annotation_data import AnnotationData
from instalabel.client.models.attribute import Attribute
from instalabel.client.models.attribute_selection import AttributeSelection
from instalabel.client.models.attribute_type import AttributeType
from instalabel.client.models.b_box_annotation import BBoxAnnotation
from instalabel.client.models.class_information import ClassInformation
from instalabel.client.models.coco_upload_request import CocoUploadRequest
from instalabel.client.models.credit_limits import CreditLimits
from instalabel.client.models.http_validation_error import HTTPValidationError
from instalabel.client.models.image_response import ImageResponse
from instalabel.client.models.ontology import Ontology
from instalabel.client.models.ontology_class import OntologyClass
from instalabel.client.models.option import Option
from instalabel.client.models.polygon_annotation import PolygonAnnotation
from instalabel.client.models.project_create import ProjectCreate
from instalabel.client.models.project_image_response import ProjectImageResponse
from instalabel.client.models.project_response import ProjectResponse
from instalabel.client.models.project_update_request import ProjectUpdateRequest
from instalabel.client.models.task_enum import TaskEnum
from instalabel.client.models.token import Token
from instalabel.client.models.validation_error import ValidationError
from instalabel.client.models.validation_error_loc_inner import ValidationErrorLocInner
from instalabel.client.models.workspace_create import WorkspaceCreate
from instalabel.client.models.workspace_credits import WorkspaceCredits
from instalabel.client.models.workspace_in_db import WorkspaceInDB
