# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instalabel.client.models.workspace_credits import WorkspaceCredits

class TestWorkspaceCredits(unittest.TestCase):
    """WorkspaceCredits unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WorkspaceCredits:
        """Test WorkspaceCredits
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WorkspaceCredits`
        """
        model = WorkspaceCredits()
        if include_optional:
            return WorkspaceCredits(
                image_uploads = instalabel.client.models.credit_limits.CreditLimits(
                    total = 56, 
                    used = 56, ),
                training_credits = instalabel.client.models.credit_limits.CreditLimits(
                    total = 56, 
                    used = 56, ),
                annotation_credits = instalabel.client.models.credit_limits.CreditLimits(
                    total = 56, 
                    used = 56, )
            )
        else:
            return WorkspaceCredits(
                image_uploads = instalabel.client.models.credit_limits.CreditLimits(
                    total = 56, 
                    used = 56, ),
                training_credits = instalabel.client.models.credit_limits.CreditLimits(
                    total = 56, 
                    used = 56, ),
                annotation_credits = instalabel.client.models.credit_limits.CreditLimits(
                    total = 56, 
                    used = 56, ),
        )
        """

    def testWorkspaceCredits(self):
        """Test WorkspaceCredits"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
